<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Supported image formats:</source>
        <translation>Formats d&apos;image supportés:</translation>
    </message>
    <message>
        <source>About Wally</source>
        <translation>A propos de Wally</translation>
    </message>
    <message>
        <source>Details &gt;&gt;</source>
        <translation>Détails &gt;&gt;</translation>
    </message>
    <message>
        <source>Compiled with:</source>
        <translation>Compilé avec:</translation>
    </message>
    <message>
        <source>EXIF library:</source>
        <translation>Librairie EXIF:</translation>
    </message>
    <message>
        <source>present</source>
        <translation>présente</translation>
    </message>
    <message>
        <source>not present</source>
        <translation>non présente</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Extension</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Additional info:</source>
        <translation>Informations supplémentaires:</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <source>Translator</source>
        <translation>Traducteur</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;/head&gt;&lt;body&gt;&lt;font size=&quot;+1&quot;&gt;Qt4 desktop wallpaper changer&lt;br /&gt;Author: Antonio Di Monaco (a.k.a. &lt;i&gt;Sin(x) &apos;76&lt;/i&gt;)&lt;br /&gt;I&apos;d like to thank Vincent Willem van Gogh for the logo :)&lt;br /&gt;&lt;br /&gt;Web site: &lt;a href=&quot;http://www.becrux.com&quot;&gt;http://www.becrux.com&lt;/a&gt;&lt;br /&gt;You can contact me at &lt;a href=&quot;mailto:tony@becrux.com?subject=About Wally&quot;&gt;tony@becrux.com&lt;/font&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;/head&gt;&lt;body&gt;&lt;font size=&quot;+1&quot;&gt;Changeur de fond d&apos;écran Qt4 &lt;br /&gt;Auteur: Antonio Di Monaco (a.k.a. &lt;i&gt;Sin(x) &apos;76&lt;/i&gt;)&lt;br /&gt;Jevoudrais remercier Vincent Willem van Gogh pour le logo :)&lt;br /&gt;&lt;br /&gt;Site web: &lt;a href=&quot;http://www.becrux.com&quot;&gt;http://www.becrux.com&lt;/a&gt;&lt;br /&gt;Vous pouvez me contacter à l&apos;adresse &lt;a href=&quot;mailto:tony@becrux.com?subject=About Wally&quot;&gt;tony@becrux.com&lt;/font&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>Italien</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Anglais</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Russe</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation>Espagnol</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>Portugais (Brésil)</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinois</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Allemand</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Czech</source>
        <translation>Tchèque</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Traductions:</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>Polonais</translation>
    </message>
    <message>
        <source>Catalan</source>
        <translation>Catalan</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Grec</translation>
    </message>
</context>
<context>
    <name>Bing::DialogWidget</name>
    <message>
        <source>All of these words</source>
        <translation>Tous ces mots</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation>N&apos;importe lequel de ces mots</translation>
    </message>
    <message>
        <source>Search for:</source>
        <translation>Rechercher:</translation>
    </message>
    <message>
        <source>Strict</source>
        <translation>Strict</translation>
    </message>
    <message>
        <source>Moderate</source>
        <translation>Modéré</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>Adult filter:</source>
        <translation>Filtre de contenu pour adulte:</translation>
    </message>
    <message>
        <source>Bing item</source>
        <translation>Recherche Bing</translation>
    </message>
    <message>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Du contenu non filtré peut montrer des photos chocantes ou sexuellement explicites</translation>
    </message>
    <message>
        <source>Edit Bing item</source>
        <translation>Editer la recherche Bing</translation>
    </message>
    <message>
        <source>Add Bing item</source>
        <translation>Ajouter une recherche Bing</translation>
    </message>
</context>
<context>
    <name>Bing::Item</name>
    <message>
        <source>Tags:</source>
        <translation>Tags:</translation>
    </message>
    <message>
        <source>and</source>
        <translation>et</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ou</translation>
    </message>
    <message>
        <source>Adult filter:</source>
        <translation>Filtre de contenu pour adulte:</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>Moderate</source>
        <translation>Modéré</translation>
    </message>
    <message>
        <source>Strict</source>
        <translation>Strict</translation>
    </message>
</context>
<context>
    <name>Buzznet::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Rechercher:</translation>
    </message>
    <message>
        <source>Edit Buzznet item</source>
        <translation>Editer la recherche Buzznet</translation>
    </message>
    <message>
        <source>Add Buzznet item</source>
        <translation>Ajouter une recherche Buzznet</translation>
    </message>
</context>
<context>
    <name>Buzznet::Item</name>
    <message>
        <source>Tag:</source>
        <translation>Tag:</translation>
    </message>
</context>
<context>
    <name>Exif::InfoDialog</name>
    <message>
        <source>EXIF information</source>
        <translation>Informations EXIF</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <source>No EXIF information available</source>
        <translation>Pas d&apos;informations EXIF disponibles</translation>
    </message>
</context>
<context>
    <name>Files::Core</name>
    <message>
        <source>Loading folder...</source>
        <translation>Chargement du dossier...</translation>
    </message>
</context>
<context>
    <name>Files::LabelPreview</name>
    <message>
        <source>No preview available</source>
        <translation>Pas de prévisualisation disponible</translation>
    </message>
</context>
<context>
    <name>Files::SettingsWidget</name>
    <message>
        <source>Select a photo</source>
        <translation>Choisir une photo</translation>
    </message>
    <message>
        <source>Select a folder</source>
        <translation>Choisir un dossier</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Fichiers</translation>
    </message>
</context>
<context>
    <name>FilesSettingsWidget</name>
    <message>
        <source>Photos</source>
        <translation>Photos</translation>
    </message>
    <message>
        <source>Add a photo</source>
        <translation>Ajouter une photo</translation>
    </message>
    <message>
        <source>Add photos in folder</source>
        <translation>Ajouter une photo dans le dossier</translation>
    </message>
    <message>
        <source>Delete photo</source>
        <translation>Supprimer la photo</translation>
    </message>
    <message>
        <source>Move photo up</source>
        <translation>Monter la photo</translation>
    </message>
    <message>
        <source>Move photo down</source>
        <translation>Descendre la photo</translation>
    </message>
</context>
<context>
    <name>Flickr::DialogWidget</name>
    <message>
        <source>All of these words</source>
        <translation>Tous ces mots</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation>N&apos;importe lequel de ces mots</translation>
    </message>
    <message>
        <source>Search for:</source>
        <translation>Rechercher:</translation>
    </message>
    <message>
        <source>Full text</source>
        <translation>Plein texte</translation>
    </message>
    <message>
        <source>Tags only</source>
        <translation>Seulement les tags</translation>
    </message>
    <message>
        <source>Largest</source>
        <translation>La plus grande</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>Originale</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Petite</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Miniature</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Carré</translation>
    </message>
    <message>
        <source>Smallest</source>
        <translation>La plus petite</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Pertinence</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Ordre:</translation>
    </message>
    <message>
        <source>Edit Flickr item</source>
        <translation>Editer la recherche Flickr</translation>
    </message>
    <message>
        <source>Add Flickr item</source>
        <translation>Ajouter une recherche Flickr</translation>
    </message>
    <message>
        <source>Interestingness desc</source>
        <translation>Intérêt décroissant</translation>
    </message>
    <message>
        <source>Date posted desc</source>
        <translation>Date de partage décroissante</translation>
    </message>
    <message>
        <source>Date taken desc</source>
        <translation>Date de prise de vue décroissante</translation>
    </message>
    <message>
        <source>Interestingness asc</source>
        <translation>Intérêt croissant</translation>
    </message>
    <message>
        <source>Date posted asc</source>
        <translation>Date de partage croissante</translation>
    </message>
    <message>
        <source>Date taken asc</source>
        <translation>Date de prise de vue croissante</translation>
    </message>
</context>
<context>
    <name>Flickr::Item</name>
    <message>
        <source>Text:</source>
        <translation>Texte:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Tags:</translation>
    </message>
    <message>
        <source>and</source>
        <translation>et</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ou</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Largest</source>
        <translation>La plus grande</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>Originale</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Petite</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Miniature</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Carré</translation>
    </message>
    <message>
        <source>Smallest</source>
        <translation>La plus petite</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Ordre:</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Pertinence</translation>
    </message>
    <message>
        <source>Interestingness desc</source>
        <translation>Intérêt décroissant</translation>
    </message>
    <message>
        <source>Date posted desc</source>
        <translation>Date de partage décroissante</translation>
    </message>
    <message>
        <source>Date taken desc</source>
        <translation>Date de prise de vue décroissante</translation>
    </message>
    <message>
        <source>Interestingness asc</source>
        <translation>Intérêt croissant</translation>
    </message>
    <message>
        <source>Date posted asc</source>
        <translation>Date de partage croissante</translation>
    </message>
    <message>
        <source>Date taken asc</source>
        <translation>Date de prise de vue croissante</translation>
    </message>
</context>
<context>
    <name>Folders::DialogWidget</name>
    <message>
        <source>Include subfolders</source>
        <translation>Inclure les sous-dossiers</translation>
    </message>
    <message>
        <source>Select a folder</source>
        <translation>Choisir un dossier</translation>
    </message>
    <message>
        <source>Edit folder</source>
        <translation>Editer le dossier</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Ajouter un dossier</translation>
    </message>
    <message>
        <source>Local</source>
        <translation>Local</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Distant</translation>
    </message>
    <message>
        <source>Folder:</source>
        <translation>Dossier:</translation>
    </message>
    <message>
        <source>Passive</source>
        <translation>Passif</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Serveur:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Transfer mode:</source>
        <translation>Mode de transfert:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;utilisateur:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe:</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Chemin:</translation>
    </message>
</context>
<context>
    <name>Folders::LocalItem</name>
    <message>
        <source>(with subfolders)</source>
        <translation>(avec les sous-dossiers)</translation>
    </message>
</context>
<context>
    <name>Folders::RemoteItem</name>
    <message>
        <source>Transfer mode:</source>
        <translation>Mode de transfert:</translation>
    </message>
    <message>
        <source>passive</source>
        <translation>passif</translation>
    </message>
    <message>
        <source>active</source>
        <translation>actif</translation>
    </message>
</context>
<context>
    <name>Folders::SettingsWidget</name>
    <message>
        <source>Folders</source>
        <translation>Dossiers</translation>
    </message>
</context>
<context>
    <name>FoldersSettingsWidget</name>
    <message>
        <source>Folders</source>
        <translation>Dossiers</translation>
    </message>
    <message>
        <source>Add a folder</source>
        <translation>Ajouter un dossier</translation>
    </message>
    <message>
        <source>Delete folder</source>
        <translation>Enlever le dossier</translation>
    </message>
</context>
<context>
    <name>Gui::ColorButton</name>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
</context>
<context>
    <name>History::Dialog</name>
    <message>
        <source>Right-click on items to show options</source>
        <translation>Faire un clic droit sur l&apos;objet pour voir les options</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>Veuillez patienter...</translation>
    </message>
    <message>
        <source>Downloading photo...</source>
        <translation>Téléchargement de la photo...</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save photo</source>
        <translation>Enregistrer la photo</translation>
    </message>
    <message>
        <source>Images (*.png *.xpm *.jpg)</source>
        <translation>Images (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <source>Photo has been saved</source>
        <translation>La photo a été enregistrée</translation>
    </message>
    <message>
        <source>There was an error during download</source>
        <translation>Il y a eu une erreur pendant le téléchargement</translation>
    </message>
    <message>
        <source>View photo...</source>
        <translation>Voir la photo...</translation>
    </message>
    <message>
        <source>Get EXIF info...</source>
        <translation>Voir les informations EXIF...</translation>
    </message>
    <message>
        <source>Save photo...</source>
        <translation>Enregistrer la photo...</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation>Utiliser comme papier-peint</translation>
    </message>
    <message>
        <source>Explore image source</source>
        <translation>Explorer la source d&apos;image</translation>
    </message>
</context>
<context>
    <name>History::EngineQueryModel</name>
    <message>
        <source>All</source>
        <translation>Tout</translation>
    </message>
</context>
<context>
    <name>History::PhotosQueryModel</name>
    <message>
        <source>Image size:</source>
        <translation>Taille d&apos;image:</translation>
    </message>
    <message>
        <source>Engine:</source>
        <translation>Moteur:</translation>
    </message>
    <message>
        <source>EXIF:</source>
        <translation>EXIF:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>(no title)</source>
        <translation>(pas de titre)</translation>
    </message>
    <message>
        <source>by:</source>
        <translation>par:</translation>
    </message>
    <message>
        <source>(no author)</source>
        <translation>(pas d&apos;auteur)</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Lieu:</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>inconnu</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Date:</translation>
    </message>
</context>
<context>
    <name>History::TagsQueryModel</name>
    <message>
        <source>All</source>
        <translation>Tout</translation>
    </message>
</context>
<context>
    <name>HttpEngine::SettingsWidget</name>
    <message>
        <source>Select a folder</source>
        <translation>Choisir un dossier</translation>
    </message>
</context>
<context>
    <name>HttpSettingsWidget</name>
    <message>
        <source>Photo sets</source>
        <translation>Ensembles de photos</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Save photos</source>
        <translation>Enregistrer les photos</translation>
    </message>
    <message>
        <source>Add a photo set</source>
        <translation>Ajouter un ensemble de photos</translation>
    </message>
    <message>
        <source>Delete photo set</source>
        <translation>Supprimer un ensemble de photos</translation>
    </message>
</context>
<context>
    <name>Ipernity::DialogWidget</name>
    <message>
        <source>All of these words</source>
        <translation>Tous ces mots</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation>N&apos;importe lequel de ces mots</translation>
    </message>
    <message>
        <source>Search for:</source>
        <translation>Rechercher:</translation>
    </message>
    <message>
        <source>Full text</source>
        <translation>Plein texte</translation>
    </message>
    <message>
        <source>Tags only</source>
        <translation>Seulement les tags</translation>
    </message>
    <message>
        <source>Edit Ipernity item</source>
        <translation>Editer la recherche Ipernity</translation>
    </message>
    <message>
        <source>Add Ipernity item</source>
        <translation>Ajouter une recherche Ipernity</translation>
    </message>
    <message>
        <source>Ipernity item</source>
        <translation>Recherche Ipernity</translation>
    </message>
    <message>
        <source>It can show offending or sexual explicit photos</source>
        <translation>Cela peut afficher des photos chocantes ou sexuellement explicites</translation>
    </message>
</context>
<context>
    <name>Ipernity::Item</name>
    <message>
        <source>Text:</source>
        <translation>Texte:</translation>
    </message>
    <message>
        <source>and</source>
        <translation>et</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ou</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Tags:</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>is already running</source>
        <translation>est déjà en cours d&apos;exécution</translation>
    </message>
    <message>
        <source>Disclaimer</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <source>&lt;b&gt;The Author takes no responsibility over the content that Wally downloads from photo sharing web sites.&lt;br&gt;The Author is in no way responsible for any such content.&lt;/b&gt;&lt;br&gt;&lt;br&gt;If this is a problem for you, please use only local engines like &quot;Files&quot; or local &quot;Folders&quot;.&lt;br&gt;Otherwise, please select &lt;b&gt;&quot;No&quot;&lt;/b&gt; to exit Wally, or use it &lt;b&gt;at your own risk.&lt;/b&gt;&lt;br&gt;&lt;br&gt;(If you proceed, this message will appear only once)&lt;br&gt;&lt;br&gt;Do you accept the above condition?</source>
        <translation>&lt;b&gt;L&apos;Auteur n&apos;a aucune responsabilité sur le contenu que Wally télécharge depuis les sites de partage de photos.&lt;br&gt;L&apos;Auteur n&apos;est en rien responsable d&apos;un tel contenu.&lt;/b&gt;&lt;br&gt;&lt;br&gt;Si cela vous pose problème, s&apos;il vous plait n&apos;utilisez que les moteurs de recherche locaux tels que &quot;Fichiers&quot; ou &quot;Dossiers&quot;.&lt;br&gt;Sinon, sélectionnez &lt;b&gt;Non&lt;/b&gt; pour quitter Wally, ou utilisez-le &lt;b&gt;à vos risques et périls.&lt;/b&gt;&lt;br&gt;&lt;br&gt;(Si vous continuez ce message n&apos;apparaitra qu&apos;une seule fois)&lt;br&gt;&lt;br&gt;Acceptez-vous les conditions ci-dessus ?</translation>
    </message>
    <message>
        <source>Another instance of</source>
        <translation>Une autre instance de</translation>
    </message>
</context>
<context>
    <name>Map::View</name>
    <message>
        <source>Drag to select. Right-click to zoom</source>
        <translation>Glisser pour sélectionner. Clic-droit pour zoomer</translation>
    </message>
    <message>
        <source>Zoom %1x</source>
        <translation>Zoom %1x</translation>
    </message>
</context>
<context>
    <name>Map::Viewer</name>
    <message>
        <source>Map viewer</source>
        <translation>Visualisation de la carte</translation>
    </message>
</context>
<context>
    <name>Panoramio::DialogWidget</name>
    <message>
        <source>Select on map</source>
        <translation>Sélectionner sur la carte</translation>
    </message>
    <message>
        <source>Longitude (min):</source>
        <translation>Longitude (min):</translation>
    </message>
    <message>
        <source>Longitude (max):</source>
        <translation>Longitude (max):</translation>
    </message>
    <message>
        <source>Latitude (min):</source>
        <translation>Latitude (min):</translation>
    </message>
    <message>
        <source>Latitude (max):</source>
        <translation>Latitude (max):</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularité</translation>
    </message>
    <message>
        <source>Upload date</source>
        <translation>Date de partage</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>Originale</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Petite</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Miniature</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Carré</translation>
    </message>
    <message>
        <source>Mini square</source>
        <translation>Mini-carré</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Ordre:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Edit Panoramio item</source>
        <translation>Editer la recherche Panoramio</translation>
    </message>
    <message>
        <source>Add Panoramio item</source>
        <translation>Ajouter une recherche Panoramio</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Coordinates must be different</source>
        <translation>Les coordonnées doivent être différentes</translation>
    </message>
</context>
<context>
    <name>Panoramio::Item</name>
    <message>
        <source>Original</source>
        <translation>Originale</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Petite</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Miniature</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Carré</translation>
    </message>
    <message>
        <source>Mini square</source>
        <translation>Mini-carré</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularité</translation>
    </message>
    <message>
        <source>Upload date</source>
        <translation>Date de partage</translation>
    </message>
    <message>
        <source>Longitude:</source>
        <translation>Longitude:</translation>
    </message>
    <message>
        <source>Latitude:</source>
        <translation>Latitude:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Ordre:</translation>
    </message>
    <message>
        <source>lat:</source>
        <translation>lat:</translation>
    </message>
    <message>
        <source>lon:</source>
        <translation>lon:</translation>
    </message>
</context>
<context>
    <name>Photobucket::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Rechercher:</translation>
    </message>
    <message>
        <source>Edit Photobucket item</source>
        <translation>Editer la recherche Photobucket</translation>
    </message>
    <message>
        <source>Add Photobucket item</source>
        <translation>Ajouter une recherche Photobucket</translation>
    </message>
    <message>
        <source>All of these words</source>
        <translation>Tous ces mots</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation>N&apos;importe lequel de ces mots</translation>
    </message>
    <message>
        <source>Photobucket item</source>
        <translation>Recherche Photobucket</translation>
    </message>
    <message>
        <source>It can show offending or sexual explicit photos</source>
        <translation>Cela peut afficher des photos chocantes ou sexuellement explicites</translation>
    </message>
</context>
<context>
    <name>Photobucket::Item</name>
    <message>
        <source>Text:</source>
        <translation>Texte:</translation>
    </message>
    <message>
        <source>and</source>
        <translation>et</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ou</translation>
    </message>
</context>
<context>
    <name>Picasa::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Rechercher:</translation>
    </message>
    <message>
        <source>Edit Picasa item</source>
        <translation>Editer la recherche Picasa</translation>
    </message>
    <message>
        <source>Add Picasa item</source>
        <translation>Ajouter une recherche Picasa</translation>
    </message>
</context>
<context>
    <name>Picasa::Item</name>
    <message>
        <source>Text:</source>
        <translation>Texte:</translation>
    </message>
</context>
<context>
    <name>Pikeo::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Rechercher:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Les plus vues</translation>
    </message>
    <message>
        <source>Upload date</source>
        <translation>Date de partage</translation>
    </message>
    <message>
        <source>Date taken</source>
        <translation>Date de prise de vue</translation>
    </message>
    <message>
        <source>Group add date</source>
        <translation>Date d&apos;ajout du groupe</translation>
    </message>
    <message>
        <source>Comment date</source>
        <translation>Date de commentaire</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation>Croissant</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Ordre:</translation>
    </message>
    <message>
        <source>Edit Pikeo item</source>
        <translation>Editer la recherche Pikeo</translation>
    </message>
    <message>
        <source>Add Pikeo item</source>
        <translation>Ajouter une recherche Pikeo</translation>
    </message>
</context>
<context>
    <name>Pikeo::Item</name>
    <message>
        <source>Tags:</source>
        <translation>Tags:</translation>
    </message>
    <message>
        <source>Order:</source>
        <translation>Ordre:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Les plus vues</translation>
    </message>
    <message>
        <source>Upload date</source>
        <translation>Date de partage</translation>
    </message>
    <message>
        <source>Date taken</source>
        <translation>Date de prise de vue</translation>
    </message>
    <message>
        <source>Group add date</source>
        <translation>Date d&apos;ajout du groupe</translation>
    </message>
    <message>
        <source>Comment date</source>
        <translation>Date de commentaire</translation>
    </message>
    <message>
        <source>ascending</source>
        <translation>croissant</translation>
    </message>
    <message>
        <source>descending</source>
        <translation>décroissant</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <source>Hu&amp;e:</source>
        <translation>&amp;Teinte:</translation>
    </message>
    <message>
        <source>&amp;Sat:</source>
        <translation>&amp;Saturation:</translation>
    </message>
    <message>
        <source>&amp;Val:</source>
        <translation>&amp;Valeur:</translation>
    </message>
    <message>
        <source>&amp;Red:</source>
        <translation>&amp;Rouge:</translation>
    </message>
    <message>
        <source>&amp;Green:</source>
        <translation>&amp;Vert:</translation>
    </message>
    <message>
        <source>Bl&amp;ue:</source>
        <translation>Ble&amp;u:</translation>
    </message>
    <message>
        <source>Select Color</source>
        <translation>Choisir les couleurs</translation>
    </message>
    <message>
        <source>&amp;Basic colors</source>
        <translation>Couleurs de &amp;base</translation>
    </message>
    <message>
        <source>&amp;Custom colors</source>
        <translation>Couleurs &amp;personnalisées</translation>
    </message>
    <message>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Ajouter aux couleurs personnalisées</translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Remise à zéro</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Oui</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Non</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <source>Directories</source>
        <translation>Dossiers</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Enregi&amp;strer</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 existe déjà.
Voulez-vous le remplacer ?</translation>
    </message>
    <message>
        <source>%1
File not found.
Please verify the correct file name was given.</source>
        <translation>%1
Fichier non trouvé.
Vérifiez que le nom de fichier.</translation>
    </message>
    <message>
        <source>My Computer</source>
        <translation>Poste de travail</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Renommer</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>Show &amp;hidden files</source>
        <translation>Afficher les fichiers cac&amp;hés</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Retour</translation>
    </message>
    <message>
        <source>Parent Directory</source>
        <translation>Dossier parent</translation>
    </message>
    <message>
        <source>List View</source>
        <translation>Liste</translation>
    </message>
    <message>
        <source>Detail View</source>
        <translation>Détails</translation>
    </message>
    <message>
        <source>Files of type:</source>
        <translation>Fichiers de type:</translation>
    </message>
    <message>
        <source>Directory:</source>
        <translation>Dossier:</translation>
    </message>
    <message>
        <source>%1
Directory not found.
Please verify the correct directory name was given.</source>
        <translation>%1
Dossier non trouvé.
Vérifiez que le bon nom de dossier a été renseigné.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is write protected.
Do you want to delete it anyway?</source>
        <translation>&apos;%1&apos; est en lecture seule.
Voulez le supprimer quand même ?</translation>
    </message>
    <message>
        <source>Are sure you want to delete &apos;%1&apos;?</source>
        <translation>Etes-vous sûr de vouloir supprimer &apos;%1&apos; ?</translation>
    </message>
    <message>
        <source>Could not delete directory.</source>
        <translation>Le dossier n&apos;a pas pu être supprimé.</translation>
    </message>
    <message>
        <source>Recent Places</source>
        <translation>Documents récents</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <source>Drive</source>
        <translation>Disque</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>Find Directory</source>
        <translation>Rechercher un dossier</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Afficher </translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Avance</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nouveau dossier</translation>
    </message>
    <message>
        <source>&amp;New Folder</source>
        <translation>&amp;Nouveau dossier</translation>
    </message>
    <message>
        <source>&amp;Choose</source>
        <translation>&amp;Choisir</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Enlever</translation>
    </message>
    <message>
        <source>File &amp;name:</source>
        <translation>&amp;Nom du fichier:</translation>
    </message>
    <message>
        <source>Look in:</source>
        <translation>Rechercher dans:</translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation>Créer un nouveau dossier</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>All image files</source>
        <translation>Tous les fichiers images</translation>
    </message>
    <message>
        <source>files</source>
        <translation>fichiers</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>kBytes</source>
        <translation>kOctets</translation>
    </message>
    <message>
        <source>MBytes</source>
        <translation>MOctets</translation>
    </message>
    <message>
        <source>GBytes</source>
        <translation>GOctets</translation>
    </message>
    <message numerus="yes">
        <source>day(s)</source>
        <translation>
            <numerusform>jour</numerusform>
            <numerusform>jours</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>month(s)</source>
        <translation>
            <numerusform>mois</numerusform>
            <numerusform>mois</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>second(s)</source>
        <translation>
            <numerusform>seconde</numerusform>
            <numerusform>secondes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>minute(s)</source>
        <translation>
            <numerusform>minute</numerusform>
            <numerusform>minutes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>hour(s)</source>
        <translation>
            <numerusform>heure</numerusform>
            <numerusform>heures</numerusform>
        </translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Vider l&apos;historique</translation>
    </message>
    <message>
        <source>Are you sure?</source>
        <translation>Etes-vous sur?</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>General options</source>
        <translation>Options générales</translation>
    </message>
    <message>
        <source>Interval:</source>
        <translation>Intervale:</translation>
    </message>
    <message>
        <source>Border:</source>
        <translation>Bordure:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrée</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Mosaïque</translation>
    </message>
    <message>
        <source>Center Tiled</source>
        <translation>Mosaïque centrée</translation>
    </message>
    <message>
        <source>Centered Maxpect</source>
        <translation>Centrée avec aspect maximal</translation>
    </message>
    <message>
        <source>Tiled Maxpect</source>
        <translation>Mosaïque avec aspect maximal</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Mise à l&apos;échelle</translation>
    </message>
    <message>
        <source>Centered Auto Fit</source>
        <translation>Centrée avec ajustement automatique</translation>
    </message>
    <message>
        <source>Scale &amp; Crop</source>
        <translation>Mise à l&apos;échelle et découpée</translation>
    </message>
    <message>
        <source>Main</source>
        <translation>Principal</translation>
    </message>
    <message>
        <source>Choose in random order</source>
        <translation>Choix aléatoire</translation>
    </message>
    <message>
        <source>Switch background on play</source>
        <translation>Change le fond d&apos;écran lors du démarrage de la lecture</translation>
    </message>
    <message>
        <source>Play automatically on application start</source>
        <translation>Lance automatiquement la lecture au démarrage de l&apos;application</translation>
    </message>
    <message>
        <source>Start automatically when system starts</source>
        <translation>Démarre automatiquement au démarrage du système</translation>
    </message>
    <message>
        <source>Only use landscape-oriented photos</source>
        <translation>Utilise uniquement des photos orientées paysage</translation>
    </message>
    <message>
        <source>Rotate images according to EXIF information</source>
        <translation>Retourne l&apos;image suivant les informations EXIF</translation>
    </message>
    <message>
        <source>View info on photo</source>
        <translation>Visualise les informations sur la photo</translation>
    </message>
    <message>
        <source>View info in system tray tooltip</source>
        <translation>Visualise les informations dans l&apos;infobulle de la barre de tâche</translation>
    </message>
    <message>
        <source>Use full desktop area</source>
        <translation>Utilise toute la zone du bureau</translation>
    </message>
    <message>
        <source>Photo has to be</source>
        <translation>La photo doit</translation>
    </message>
    <message>
        <source>independent of</source>
        <translation>être indépendante de</translation>
    </message>
    <message>
        <source>at least 1/2 of</source>
        <translation>avoir une taille d&apos;au moins 1/2 de</translation>
    </message>
    <message>
        <source>at least 3/4 of</source>
        <translation>avoir une taille d&apos;au moins 3/4 de</translation>
    </message>
    <message>
        <source>bigger than</source>
        <translation>être plus grande que</translation>
    </message>
    <message>
        <source>desktop&apos;s size</source>
        <translation>la taille du bureau</translation>
    </message>
    <message>
        <source>Store images in history for</source>
        <translation>Enregistre les images dans l&apos;historique pendant</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Vider l&apos;historique</translation>
    </message>
    <message>
        <source>Direct connection</source>
        <translation>Connexion directe</translation>
    </message>
    <message>
        <source>Proxy connection</source>
        <translation>Connexion par proxy</translation>
    </message>
    <message>
        <source>Don&apos;t save locally remote photos if free disk space goes below</source>
        <translation>Ne pas enregistrer les photos distantes en local si l&apos;espace libre descend en dessous de</translation>
    </message>
    <message>
        <source>Available modules:</source>
        <translation>Modules disponibles:</translation>
    </message>
    <message>
        <source>Active modules:</source>
        <translation>Modules actifs:</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <source>Use system proxy</source>
        <translation>Utilse le proxy du système</translation>
    </message>
    <message>
        <source>Use custom proxy</source>
        <translation>Utilise un proxy personnalisé</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentification</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;utilisateur:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe:</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Serveur:</translation>
    </message>
    <message>
        <source>Changes won&apos;t be applied. Are you sure?</source>
        <translation>Les changements ne seront pas appliqués. Etes-vous sur?</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
</context>
<context>
    <name>SmugMug::DialogWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Rechercher:</translation>
    </message>
    <message>
        <source>Edit SmugMug item</source>
        <translation>Editer la recherche SmugMug</translation>
    </message>
    <message>
        <source>Add SmugMug item</source>
        <translation>Ajouter une recherche SmugMug</translation>
    </message>
</context>
<context>
    <name>SmugMug::Item</name>
    <message>
        <source>Text:</source>
        <translation>Texte:</translation>
    </message>
</context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>Author:</source>
        <translation>Auteur:</translation>
    </message>
    <message>
        <source>Loading Files module ...</source>
        <translation>Chargement du module Fichier ...</translation>
    </message>
    <message>
        <source>Loading Folders module ...</source>
        <translation>Chargement du module Dossier ...</translation>
    </message>
    <message>
        <source>Loading Flickr module ...</source>
        <translation>Chargement du module Flickr ...</translation>
    </message>
    <message>
        <source>Loading Yahoo! module ...</source>
        <translation>Chargement du module Yahoo! ...</translation>
    </message>
    <message>
        <source>Loading Panoramio module ...</source>
        <translation>Chargement du module Panoramio ...</translation>
    </message>
    <message>
        <source>Loading Pikeo module ...</source>
        <translation>Chargement du module Pikeo ...</translation>
    </message>
    <message>
        <source>Loading Ipernity module ...</source>
        <translation>Chargement du module Ipernity ...</translation>
    </message>
    <message>
        <source>Loading Photobucket module ...</source>
        <translation>Chargement du module Photobucket ...</translation>
    </message>
    <message>
        <source>Loading Buzznet module ...</source>
        <translation>Chargement du module Buzznet ...</translation>
    </message>
    <message>
        <source>Loading Picasa module ...</source>
        <translation>Chargement du module Picasa ...</translation>
    </message>
    <message>
        <source>Loading SmugMug module ...</source>
        <translation>Chargement du module SmugMug ...</translation>
    </message>
    <message>
        <source>Loading Bing module ...</source>
        <translation>Chargement du module Bing ...</translation>
    </message>
    <message>
        <source>Loading settings ...</source>
        <translation>Chargement des paramètres ...</translation>
    </message>
    <message>
        <source>Launching Wally ...</source>
        <translation>Lancement de Wally ...</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <source>Right-click on photo to show actions</source>
        <translation>Faire un clic droit sur la photo pour voir les actions</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajuste à la fenêtre</translation>
    </message>
    <message>
        <source>Show full image</source>
        <translation>Zoom 1:1</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Agrandir</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Tourner dans le sens horaire</translation>
    </message>
    <message>
        <source>Rotate c. clockwise</source>
        <translation>Tourner dans le sens antihoraire</translation>
    </message>
</context>
<context>
    <name>Wally::Application</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Next photo</source>
        <translation>Photo suivante</translation>
    </message>
    <message>
        <source>Save photo...</source>
        <translation>Enregistrer la photo...</translation>
    </message>
    <message>
        <source>Get EXIF info...</source>
        <translation>Voir les informations EXIF...</translation>
    </message>
    <message>
        <source>Settings...</source>
        <translation>Paramètres...</translation>
    </message>
    <message>
        <source>Explore source</source>
        <translation>Explorer la source</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>A propos de...</translation>
    </message>
    <message>
        <source>History...</source>
        <translation>Historique...</translation>
    </message>
    <message>
        <source>About Qt...</source>
        <translation>A propos de Qt...</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Anglais</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>Italien</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation>Espagnol</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Allemand</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Russe</translation>
    </message>
    <message>
        <source>Czech</source>
        <translation>Tchèque</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinois</translation>
    </message>
    <message>
        <source>Languages</source>
        <translation>Langues</translation>
    </message>
    <message>
        <source>by:</source>
        <translation>par:</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Lieu:</translation>
    </message>
    <message>
        <source>Engine:</source>
        <translation>Moteur:</translation>
    </message>
    <message>
        <source>Save photo</source>
        <translation>Enregistrer la photo</translation>
    </message>
    <message>
        <source>Images (*.png *.xpm *.jpg)</source>
        <translation>Images (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <source>Right-click to show main menu</source>
        <translation>Faire un clic droit pour voir le menu principal</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>Portugais (Brésil)</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>Polonais</translation>
    </message>
    <message>
        <source>Wally Error</source>
        <translation>Erreur Wally</translation>
    </message>
    <message>
        <source>Active Desktop must be disabled</source>
        <translation>Active Desktop doit être désactivé</translation>
    </message>
    <message>
        <source>Catalan</source>
        <translation>Catalan</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Grec</translation>
    </message>
</context>
<context>
    <name>Yahoo::DialogWidget</name>
    <message>
        <source>All of these words</source>
        <translation>Tous ces mots</translation>
    </message>
    <message>
        <source>Any of these words</source>
        <translation>N&apos;importe lequel de ces mots</translation>
    </message>
    <message>
        <source>Search for:</source>
        <translation>Rechercher:</translation>
    </message>
    <message>
        <source>Filter content</source>
        <translation>Filtrer le contenu</translation>
    </message>
    <message>
        <source>Yahoo! item</source>
        <translation>Recherche Yahoo!</translation>
    </message>
    <message>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Du contenu non filtré peut montrer des photos chocantes ou sexuellement explicites</translation>
    </message>
    <message>
        <source>Edit Yahoo! item</source>
        <translation>Editer la recherche Yahoo!</translation>
    </message>
    <message>
        <source>Add Yahoo! item</source>
        <translation>Ajouter une recherche Yahoo!</translation>
    </message>
</context>
<context>
    <name>Yahoo::Item</name>
    <message>
        <source>Tags:</source>
        <translation>Tags:</translation>
    </message>
    <message>
        <source>and</source>
        <translation>et</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ou</translation>
    </message>
    <message>
        <source>content filtered</source>
        <translation>contenu filtré</translation>
    </message>
</context>
</TS>
